==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFilteringExpressionsTreeOrFilteringExpressionDescription } from "./WebFilteringExpressionsTreeOrFilteringExpressionDescription";
/**
 * @hidden
 */
export let WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata extends Base {
        static b(a) {
            if (WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata.a == null) {
                WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata.c(WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata.a);
            }
            if (a.k(WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:FilteringExpressionsTreeOrFilteringExpression");
        }
        static d(a) {
            WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata.b(a);
            a.ad("WebFilteringExpressionsTreeOrFilteringExpression", () => new WebFilteringExpressionsTreeOrFilteringExpressionDescription());
            a.ac("WebFilteringExpressionsTreeOrFilteringExpression", WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata.a);
        }
    }
    WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata.$t = markType(WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata, 'WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata');
    WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata.a = null;
    return WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebExpressionTreeOrFilteringExpressionDescriptionMetadata } from "./WebExpressionTreeOrFilteringExpressionDescriptionMetadata";
import { WebFilteringExpressionsTreeOrFilteringExpressionDescription } from "./WebFilteringExpressionsTreeOrFilteringExpressionDescription";
/**
 * @hidden
 */
export let WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata extends Base {
        static b(a) {
            if (WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata.a == null) {
                WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata.c(WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata.a);
            }
            if (a.k(WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata.a);
        }
        static c(a) {
            WebExpressionTreeOrFilteringExpressionDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:FilteringExpressionsTreeOrFilteringExpression");
        }
        static d(a) {
            WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata.b(a);
            a.ae("WebFilteringExpressionsTreeOrFilteringExpression", () => new WebFilteringExpressionsTreeOrFilteringExpressionDescription());
            a.ad("WebFilteringExpressionsTreeOrFilteringExpression", WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata.a);
        }
    }
    WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata.$t = markType(WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata, 'WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata');
    WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata.a = null;
    return WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata;
})();
